<div class="modal fade" id="deleteProject" tabindex="-1" aria-labelledby="deleteProjectLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <form action="{{ url_for('project.delete_project', projectname=projectname) }}" method="POST"
                data-reload-location="1">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteProjectLabel">
                        <span>Delete Project</span>
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>Are you sure you want to delete the project
                    <p><strong>{{ projectname }}</strong>?</p>
                    This action cannot be undone.</p>
                    <p>All associated data will be permanently removed.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-danger">Delete</button>
                </div>
            </form>
        </div>
    </div>
</div>