<!DOCTYPE html>
<div class="col-12 text-center">
    {% if not tg_session_id %}
    <!-- Show note when no session ID is set -->
    <div class="alert alert-warning fst-italic">
        <h6 class="fw-bold">Attention</h6>
        <p>
            <b>You need to provide a "TgAuth Session ID" in order to {{action}} your project to
                TextGrid-{{ instance|capitalize }} Instance!</b>
        </p>
        <ol class="mb-0">
            <li>Please first go to <a href="{{ get_textgrid_login_url(instance) }}" target="_blank">this
                    page</a>!
                (You may need to log in via DARIAH-AAI)</li>
            <li>Then click on "More Details" and copy the "TgAuth Session ID" to your clipboard.</li>
            <li>Finally, paste it into the input field below and save it.</li>
        </ol>
    </div>
    {% elif not is_valid_session %}
    <!-- Show note when session ID is invalid -->
    <div class="alert alert-warning fst-italic">
        <h6 class="fw-bold">Attention</h6>
        <p>
            It looks like the given <b>Session ID is invalid</b>. Please try again and, if needed, check <a
                href="{{ get_textgrid_login_url(instance) }}" target="_blank">here</a> again.
        </p>
    </div>
    {% endif %}
</div>