<!DOCTYPE html>
<div class="container py-4">
    <div class="row">
        <!-- Page Title -->
        <div class="col-12 text-center mb-4">
            <h1 class="fs-3 fw-bold">Upload Project</h1>
        </div>
        <!-- Instanzauswahl -->
        <div class="col-12 mb-4">
            <h4 class="text-center mb-3">Choose the instance:</h4>
            <ul class="nav nav-tabs justify-content-center" id="instanceTabs" role="tablist">
                <li class="nav-item" role="presentation">
                    <button class="nav-link active" id="test-tab" data-bs-toggle="tab" data-bs-target="#test-pane"
                        type="button" role="tab" aria-controls="test-pane" aria-selected="true">
                        Test
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="prod-tab" data-bs-toggle="tab" data-bs-target="#prod-pane"
                        type="button" role="tab" aria-controls="prod-pane" aria-selected="false">
                        Live
                    </button>
                </li>
            </ul>
        </div>

        <!-- Tab-Inhalte -->
        <div class="tab-content">
            <!-- Testinstanz -->
            <div class="tab-pane fade show active" id="test-pane" role="tabpanel" aria-labelledby="test-tab">
                {% set instance='test' %}
                {% include 'includes/upload_form.html' %}
            </div>

            <!-- Produktionsinstanz -->
            <div class="tab-pane fade" id="prod-pane" role="tabpanel" aria-labelledby="prod-tab">
                {% set instance='live' %}
                {% include 'includes/upload_form.html' %}
            </div>
        </div>
    </div>
</div>