<div class="h2">Nextcloud Login</div>
<form class="form-group login" method="POST" action="" id="nextcloud_login">
    <div class="col-6">
        <small class="form-text text-muted">Url</small>
        <input required type="text" class="form-control" name="nextcloud_url" placeholder="Enter Nextcloud URL">
    </div>
    <div class="form-group col-3">
        <small class="form-text text-muted">Username</small>
        <input required type="text" class="form-control" name="username" id="username" placeholder="Enter Username">
    </div>
    <div class="form-group col-3">
        <small class="form-text text-muted">Password</small>
        <input required type="password" class="form-control" name="password" id="password" placeholder="Password">
    </div>
    <div class="form-group col-3">
        <small class="form-text text-muted">Directory</small>
        <input type="text" class="form-control" name="root_dir" id="root_dir" placeholder="(e.g.) TextGrid">
    </div>
    <br>
    <button type="submit" class="btn btn-primary p-2 m-3 submit-login">
        Submit
        <span class="spinner-border spinner-border-sm spinner-login" hidden></span>
    </button>
    <span class="alert alert-danger" id="login-error" hidden>Wrong credentials</span>
</form>