/* Hover- und Active-Styles für kleine runde Buttons */
.btn-circle.btn-sm:hover,
.btn-circle.btn-sm:focus {
    background-color: #e9ecef;
    color: #0d6efd;
    border-color: #0d6efd;
    cursor: pointer;
    transition: background 0.2s, color 0.2s, border 0.2s;
}

.btn-circle.btn-sm.btn-outline-primary,
.btn-circle.btn-sm.last-opened {
    background-color: #0d6efd;
    color: #fff;
    border-color: #0d6efd;
}
.btn-circle.btn-xl {
    width: 4.2rem;
    height: 4.2rem;
    border-radius: 50%;
    text-align: center;
    font-size: 1.5rem;
    display: flex;
    justify-content: center;
    align-items: center;
    position: relative;
    z-index: 1;
}

.btn-circle.btn-sm {
    width: 3.2rem;
    height: 3.2rem;
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;

}

/* Animation für den Übergang */
.btn-xl.animate-to-long {
    width: 25rem;
    height: 4.2rem;
    border-width: 0.2rem;
    border-radius: 3rem;
    transition: all 5.2s ease-in-out;
    display: flex;
    justify-content: center;
    align-items: center;
}

.btn-xl.animate-to-long i .main-icon {
    opacity: 0;
    /* Icon ausblenden */
    transition: opacity 0.3s ease-in-out;
    /* Sanftes Ausblenden */
}

.line {
    height: 20px;
    border-radius: 10px;
    position: absolute;
    top: 50%;
    height: 4px;
}

.line.blank {
    width: 95%;
    background-color: #f8f9fa;
    left: 1rem;
    z-index: 0;
}

.line.blue {
    width: 0%;
    background-color: #0d6efd;
    left: 1rem;
    z-index: 0.5;
    transition: width 0.3s ease-in-out;
}

.btn-xl.animate-to-long {
    z-index: 2;
    /* Erweiterte Buttons über die Linie legen */
    transition: all 0.3s ease-in-out;
}

.border-primary{
    border-width: 0.2rem;
    transition: all 0.2s ease-in-out;
}


/* tab-edit-other-files */
.tab-button {
    width: 12rem;
    height: 12rem;
    color: #0d6efd;
}

.tab-button.active,
.tab-button:active {
    background-color: #FFFFFF !important;
}

.big-icon {
    font-size: 5rem;
}
