<!DOCTYPE html>
<div class="card-body" id="detailsContent">
    {% if show_spinner %}
    <div class="text-center text-muted">
        <div class="spinner-border text-secondary" role="status">
            <span class="visually-hidden">Loading...</span>
        </div>
    </div>
    {% else %}
    <p class="text-muted">Select a collection to view or edit its details.</p>
    <div class="text-center text-muted">
        <i class="bi bi-info-circle" style="font-size: 2rem;"></i>
        <p>No collection selected.</p>
    </div>
    {% endif %}
</div>