<div class="modal fade" id="githubModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Clone from GitHub</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <form class="reloadModal" action="{{ url_for('data.clone_git_project', projectname=project.name) }}"
                    method="POST" id="cloneFromGit">
                    <div class="mb-3">
                        <input type="text" class="form-control" name="github_repo" placeholder="GitHub Repository URL">
                    </div>
                    <div class="d-flex justify-content-between align-items-center">
                        <small class="text-muted">
                            <i>Please be aware, that this can take a while (depending on the size of the git
                                project)!</i>
                        </small>
                    </div>
                    <button type="submit" class="btn btn-primary mt-3">
                        <span class="spinner-border spinner-border-sm me-2 d-none" role="status"
                            aria-hidden="true"></span>
                        <span>Clone Repository</span>
                    </button>
                </form>
            </div>
        </div>
    </div>
</div>