{% if nextcloud %}
<div class="h2">{{user}}'s Folders</div>
{% for item in nextcloud.nxc_list_files_and_folders() %}
{% include 'nxc_file_tree.html' %}
{% endfor %}
<button type="submit" class="btn btn-primary p-2 m-3 submit-selection">
    Submit
    <span class="spinner-border spinner-border-sm spinner-submit" hidden></span>
</button>
<button type="button" class="btn btn-secondary p-2 m-3" id="nextcloud_logout" onclick="handleLogout()">
    Logout
</button>
{% else %}
{% include 'nxc_login.html' %}
{% endif %}