<div class="modal fade" id="folderModal{{ index }}" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">
                    <i class="bi bi-folder2-open text-warning me-2"></i>
                    {{ folder.name }}
                </h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                {% if folder.children.count > 0 %}
                {% with items=folder.children.list %}
                {% include 'modal/file_explorer_content.html' %}
                {% endwith %}
                {% else %}
                <p class="text-muted text-center py-3">Dieser Ordner ist leer</p>
                {% endif %}
            </div>
        </div>
    </div>
</div>