<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />
    <meta name="description" content="" />
    <meta name="author" content="" />
    <title>{{ title }}</title>
    <link rel="icon" type="image/x-icon" href="{{ url_for('static', filename='img/favicon.ico') }}" />
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/bootstrap.min.css') }}" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/simpleXML.css') }}" />
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/main.css') }}" />
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/navbar.css') }}" />
</head>

<body>
    <div class="wrapper">
        <aside id="sidebar" class="expand d-flex flex-column">
            <div class="d-flex">
                <button class="toggle-btn" type="button">
                    <i class="bi bi-grid"></i>
                </button>
                <div class="sidebar-logo">
                    <a href="#">{{ title }}</a>
                </div>
            </div>
            <ul class="p-0 flex-grow-1 overflow-y-auto">
                <li class="sidebar-item">
                    <div class="d-flex align-items-center px-3 py-0 text-light">
                        <a href="{{ url_for('views.overview') }}" class="sidebar-link px-0 hover-none" title="Overview">
                            <i class="bi bi-view-list"></i>
                            <span>Overview</span>
                        </a>
                    </div>
                </li>
                {% for project in get_projects() %}
                <li class="sidebar-item project-btn">
                    <a href="{{ url_for('views.project_view', projectname=project.name) }}" class="sidebar-link"
                        data-bs-target="#project_{{ loop.index }}" aria-expanded="false"
                        aria-controls="project_{{ loop.index }}">
                        {% if current_project == project.name %}
                        <i class="bi bi-circle-fill"></i>
                        {% else %}
                        <i class="bi bi-circle"></i>
                        {% endif %}
                        <span class="projectname">{{ project.name }}</span>
                    </a>
                </li>
                {% endfor %}
                <li class="sidebar-item">
                    <a href="{{ url_for('views.overview') }}" class="sidebar-link" title="Add a new project"
                        data-bs-toggle="modal" data-bs-target="#newProject">
                        <i class="bi bi-file-plus"></i>
                        <span>New Project</span>
                    </a>
                </li>
            </ul>
        </aside>
        <div class="main p-3">
            {% block content %}{% endblock content %}
            {% include 'modal/empty_container.html' %}
            {% include 'modal/new_project.html' %}
        </div>
    </div>
    <script data-main="{{ url_for('static', filename='js/main.js') }}"
        src="{{ url_for('static', filename='js/require.js') }}"></script>
</body>

</html>